@@ -12,18 +12,9 @@ set_worker_name() {
     local config="$1"
     local miner_name="$2"
 
-    # Case 1: Has worker name (dot after hash)
-    if echo "$config" | grep -qE '--user[[:space:]]+hoosat:[0-9a-fA-F]{64}\.'; then
-        # Append _minername to existing worker
-        echo "$config" | sed -E "s/(--user[[:space:]]+hoosat:[0-9a-fA-F]{64}\.[^[:space:]]*)/\1_${miner_name}/"
-    # Case 2: No worker name (just hash)
-    elif echo "$config" | grep -qE '--user[[:space:]]+hoosat:[0-9a-fA-F]{64}([[:space:]]|$)'; then
-        # Add new worker name with underscore
-        echo "$config" | sed -E "s/(--user[[:space:]]+hoosat:[0-9a-fA-F]{64})/\1_${miner_name}/"
-    else
-        # No valid --user found; leave config unchanged
-        echo "$config"
-    fi
+    echo "$config" | sed -E \
+        -e "s/(--user[[:space:]]+hoosat:[0-9a-fA-F]{64})\.([^[:space:]]+)/\1.\2_${miner_name}/" \
+        -e "s/(--user[[:space:]]+hoosat:[0-9a-fA-F]{64})([[:space:]]|$)/\1.${miner_name}\2/"
 }
 
 # --- Run miners in parallel ---
